@@ -1,6 +1,6 @@
 package Test::Mocha::Mock;
 {
-  $Test::Mocha::Mock::VERSION = '0.17';
+  $Test::Mocha::Mock::VERSION = '0.18';
 }
 # ABSTRACT: Mock objects
 
@@ -53,7 +53,7 @@ sub AUTOLOAD {
     # find a stub to return a response
     if (defined $stubs->{$method_name}) {
         foreach my $stub ( @{$stubs->{$method_name}} ) {
-            return $stub->do_next_execution(@args)
+            return $stub->do_next_execution($self, @args)
                 if $stub->satisfied_by($method_call);
         }
     }
